@@ -19,7 +19,7 @@ limitations under the License.
 package Bio::DB::HTS::Tabix::Iterator;
 
 use Bio::DB::HTS; #load the XS
-$Bio::DB::HTS::Tabix::Iterator::VERSION = '1.12';
+$Bio::DB::HTS::Tabix::Iterator::VERSION = '1.13';
 
 use strict;
 use warnings;
@@ -62,9 +62,17 @@ sub close {
     #xs method
     if ( defined $self->{_tabix_iter} ) {
         tbx_iter_free($self->{_tabix_iter});
+        delete $self->{_tabix_iter}; # delete once you've removed it. Prevents bad re-issuing of code
     }
 }
 
+sub DESTROY {
+    my $self = shift;
+    return if ref($self) ne 'HASH';
+    $self->close();
+    return;
+}
+
 1;
 
 __END__
